
# THIS FILE IS GENERATED FROM wofry SETUP.PY
short_version = '1.0.30'
version = '1.0.30'
full_version = '1.0.30'
git_revision = '07d1d00c828599b225a96e44713911830b3f0d6b'
release = True

if not release:
    version = full_version
    short_version += ".dev"
